! -*- Mode: f90 -*-
!> Module dimensions
!!   
MODULE dimensions
   !!
   USE declare
   IMPLICIT NONE
   SAVE
   PUBLIC
   !!
   CHARACTER (len=10) :: c_period = 'none' ! or lgm, mpwp, etc ...
   !!
   INTEGER (kind=il)   :: jpoi  !< Dimensions ocean X
   INTEGER (kind=il)   :: jpoj  !< Dimensions ocean Y
   CHARACTER (len = 3) :: comod  !< Ocean model name
   CHARACTER (len = 10) :: cotyp  !< Ocean model type
   INTEGER (kind=il)   :: jpon   !< Global (1D) dimensions
   !!
   REAL (kind=rl) :: epsfrac = 1.0E-10_rl  !< Min fraction of sea acceptable. To check : should be compatible with EPSFRA in LMDZ ?
   !
   INTEGER (kind=il) :: jpoe !< Number (maxi) of edges to describe ocean box
   !!
   INTEGER (kind=il) :: noperio !< Periodicity of ocean grid
   LOGICAL :: lmasko=.FALSE.  !< If TRUE, masked points of oceanic     grid (land) are considered for computing.
   LOGICAL :: l_recalc_o = .TRUE. !< Recalcule des surfaces ocean
   CHARACTER (len=280) :: c_oce_msk_file = 'NONE'
   !!
   INTEGER (kind=il) :: jpai, jpait, jpaiu, jpaiv !< Dimensions atmosphere X
   INTEGER (kind=il) :: jpaj, jpajt, jpaju, jpajv !< Dimensions atmosphere Y

   CHARACTER (LEN=80)  :: c_suffix  = 'none' ! Add a suffix to all file names
   CHARACTER (LEN=240) :: c_comment = 'none' ! Add a comment in all NetCDF Files
   
   CHARACTER (len = 3) :: camod    !< Atm model name
   CHARACTER (len = 10) :: catyp   !< Atm model type
   !!
   INTEGER (kind=il) :: naperio !< Periodicite de la grille atmosphere
   LOGICAL :: lmaska=.TRUE.     !< If TRUE, masked points of atmospheric grid (land) are considered for computing.
   LOGICAL :: la_nortop         !< If TRUE, latitude indreases with index in output files
   LOGICAL :: l_recalc_a = .TRUE. !< Recalcule des surfaces atmospheres
   LOGICAL :: la_pole !< IF TRUE, special handing of atmospheric pole points
   !!
   INTEGER (kind=il) :: jpae !< Number (maxi) of edges to describe atm box
   !!
   INTEGER (kind=il) :: jpan  !< Dimension of 1D atm array, T grid
   INTEGER (kind=il) :: jpanu !< Dimension of 1D atm array, U grid
   INTEGER (kind=il) :: jpanv !< Dimension of 1D atm array, V grid
   !!
   LOGICAL :: lwra2o=.TRUE. !< TRUE if atm -> oce weights/adresses are computed
   LOGICAL :: lwro2a=.TRUE. !< TRUE if oce -> atm weights/adresses are computed
   INTEGER (kind=il) :: norma2o=1 !< Type of normalization atm-> oce: 0: none, 1: intensive, 2: extensive
   INTEGER (kind=il) :: normo2a=1 !< Type of normalization oce -> atm: 0: none, 1: intensive, 2: extensive
   !!
   INTEGER (kind=il) :: jpa2o !< Dimensions for computing weights, atm -> oce
   INTEGER (kind=il) :: jpo2a !< Dimensions for computing weights, oce -> atm
   !!
   LOGICAL :: limit_stack !< If true, limit stack size in NetCDF calls, by slicing output operation
   LOGICAL :: l_grid_cdf  !< If TRUE, read grid specification in NetCDF format
   !! LOGICAL :: l_wei_cdf   !< if TRUE, read weights and adresses in NetCDF (Oasis 3 format)
   LOGICAL :: l_wei_i4    !< if TRUE, write adresses in INTEGER*4
   LOGICAL :: l_wei_i8    !< if TRUE, write adresses in INTEGER*8
   LOGICAL :: l_wei_oasis_3   !< if TRUE, write Oasis 3 weight file
   LOGICAL :: l_wei_oasis_mct !< if TRUE, write Oasis MCT weight file
   LOGICAL :: l_limit_iosize !< If TRUE, don't do full diagnostics in cotes.f90
   CHARACTER (LEN=10) :: c_read_wei = 'oasis_3'
   CHARACTER (len=64) :: c_FlioMode   !< Flio file format
   CHARACTER (len=3) :: c_oasis !< Oasis version
   integer (kind=il) :: slice_size !< Slice size for writing NetCDF files
   !!
   LOGICAL :: locerev !< Strategie de nommage des champs ocean
   LOGICAL :: latmrev !< Strategie de nommage des champs atmosphere
   !!
   INTEGER (kind=il)            :: jmo2a    !< Maximum number of found neighbors, ocean -> atmosphere
   INTEGER (kind=il)            :: jma2o    !< Maximum number of found neighbors, atmosphere -> ocean
   INTEGER (kind=il)            :: jma2or   !< Maximum number of found neighbors : run-off
   INTEGER (kind=il)            :: jma2oi   !< Maximum number of found neighbors : icestream
   !!
   REAL (kind=rl) :: xa_inf !< Minimum value of atm longitudes
   REAL (kind=rl) :: xa_sup !< Maximum value of atm longitudes
   REAL (kind=rl) :: ya_inf !< Minimum value of atm latitudes
   REAL (kind=rl) :: ya_sup !< Maximum value of atm latitudes
   REAL (kind=rl) :: xo_inf !< Minimum value of oce longitudes
   REAL (kind=rl) :: xo_sup !< Maximum value of oce longitudes
   REAL (kind=rl) :: yo_inf !< Minimum value of oce latitudes
   REAL (kind=rl) :: yo_sup !< Maximum value of oce latitudes
   !!
   !
   LOGICAL :: l_fast !< Quick and dirty version, for test only
   !!
   LOGICAL :: l_dryrun              !< Flag for fast and dirty search
   LOGICAL :: l_ipsldbg             !< Flag for debugging IOIPSL operations
   INTEGER (kind=il) :: lev_dry     !< For dry run : use to test I/O
   INTEGER (kind=il) :: ndebug=2    !< Levels of printing
   CHARACTER (len=20) :: o2a_orien="nord_en_haut"  !< Orientation for o2a diag file
   !!
   !! Basins
   CHARACTER (len=40) :: cl_atl, cl_pac, cl_noclo, cl_nomed, c_basins
   !!
   !! Poids run-off
   !!
   LOGICAL :: lriv     !< Traitement du runoff des rivires
   LOGICAL :: lcoast   !< Traitement specifique des points cotiers
   LOGICAL :: lint_atm !< Calcul pour run-off intgr sur la maille atm
   LOGICAL :: lint_oce !< Calcul pour run-off intgr sur la maille oce
   LOGICAL :: lnear    !< Route le run-off des pts atm 'proches' de la cote vers le point oce le plus proche
   LOGICAL :: lnei     !< Si vrai, route le run-off des points atm 'proches' de la cote vers les point atmosphres mouilles les plus proches.
   LOGICAL :: ltotal          !< Route tout les points atm vers l'oce le plus proche.
   LOGICAL :: ltotal_dist     !< Route tout les points atm vers l'oce le plus proche, avec distance maxi
   LOGICAL :: ltotal_dist_2   !< Route tout les point atm vers les oce cotiers le plus proche, avec distance maxi
   LOGICAL :: ltotal_dist_3   !< Route tout les point atm vers les oce le plus proche, cotiers ou pas, avec distance maxi
   LOGICAL :: l_etal_oce   !
   REAL (kind=rl) :: dist_etal_oce
   LOGICAL :: lessai          !< Cas en test
   CHARACTER (len=20) :: cotes_omsk, cotes_amsk
   REAL    (kind=rl), DIMENSION (:), ALLOCATABLE :: dist_coast_o, dist_coast_a
   !
   LOGICAL, DIMENSION (:), ALLOCATABLE :: lacot, laland, laoce, lanoroute, la_nearcoast
   LOGICAL, DIMENSION (:), ALLOCATABLE :: locot, looce, lo_nearcoast
   !
   REAL (kind=rl) :: dist_max        = r_earth !< Earth radius
   REAL (kind=rl) :: dist_max_atm    = 400.0E3_rl !< Max distance for searching next atm neighbours
   REAL (kind=rl) :: dist_max_oce    = 400.0E3_rl !< Max distance for searching the ocean points
   REAL (kind=rl) :: dist_max_large  = 400.0E3_rl !< Another max distance ...
   LOGICAL :: l_large = .TRUE. !< @todo a commenter ...
   !!
   !! Poids icestream
   !!
   INTEGER (kind=il) :: jp_calv ! Nombre de zone de collectes
   REAL (kind=rl), DIMENSION (:), ALLOCATABLE :: ylimits
   LOGICAL :: l_calving_nomed !< Calving does not go to mediterranean sea (include Red Sea, Persian Gul)
   LOGICAL :: l_calving_noatl !< Calving does not go to Atlantic
   LOGICAL :: l_calving_nopac !< Calving does not go to Pacific
   
   !!
END MODULE dimensions
